# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/filters.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import latlng_pb2 as google_dot_type_dot_latlng__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/filters.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\014FiltersProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n/google/cloud/talent_v4beta1/proto/filters.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x18google/type/latlng.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1cgoogle/api/annotations.proto"\x80\x05\n\x08JobQuery\x12\r\n\x05query\x18\x01 \x01(\t\x12\x1b\n\x13query_language_code\x18\x0e \x01(\t\x12\x11\n\tcompanies\x18\x02 \x03(\t\x12\x45\n\x10location_filters\x18\x03 \x03(\x0b\x32+.google.cloud.talent.v4beta1.LocationFilter\x12@\n\x0ejob_categories\x18\x04 \x03(\x0e\x32(.google.cloud.talent.v4beta1.JobCategory\x12\x42\n\x0e\x63ommute_filter\x18\x05 \x01(\x0b\x32*.google.cloud.talent.v4beta1.CommuteFilter\x12\x1d\n\x15\x63ompany_display_names\x18\x06 \x03(\t\x12L\n\x13\x63ompensation_filter\x18\x07 \x01(\x0b\x32/.google.cloud.talent.v4beta1.CompensationFilter\x12\x1f\n\x17\x63ustom_attribute_filter\x18\x08 \x01(\t\x12\x1b\n\x13\x64isable_spell_check\x18\t \x01(\x08\x12\x45\n\x10\x65mployment_types\x18\n \x03(\x0e\x32+.google.cloud.talent.v4beta1.EmploymentType\x12\x16\n\x0elanguage_codes\x18\x0b \x03(\t\x12G\n\x12publish_time_range\x18\x0c \x01(\x0b\x32+.google.cloud.talent.v4beta1.TimestampRange\x12\x15\n\rexcluded_jobs\x18\r \x03(\t"\xf5\x08\n\x0cProfileQuery\x12\r\n\x05query\x18\x01 \x01(\t\x12\x45\n\x10location_filters\x18\x02 \x03(\x0b\x32+.google.cloud.talent.v4beta1.LocationFilter\x12\x46\n\x11job_title_filters\x18\x03 \x03(\x0b\x32+.google.cloud.talent.v4beta1.JobTitleFilter\x12\x45\n\x10\x65mployer_filters\x18\x04 \x03(\x0b\x32+.google.cloud.talent.v4beta1.EmployerFilter\x12G\n\x11\x65\x64ucation_filters\x18\x05 \x03(\x0b\x32,.google.cloud.talent.v4beta1.EducationFilter\x12?\n\rskill_filters\x18\x06 \x03(\x0b\x32(.google.cloud.talent.v4beta1.SkillFilter\x12Q\n\x16work_experience_filter\x18\x07 \x03(\x0b\x32\x31.google.cloud.talent.v4beta1.WorkExperienceFilter\x12=\n\x0ctime_filters\x18\x08 \x03(\x0b\x32\'.google.cloud.talent.v4beta1.TimeFilter\x12\x32\n\x0ehirable_filter\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12T\n\x18\x61pplication_date_filters\x18\n \x03(\x0b\x32\x32.google.cloud.talent.v4beta1.ApplicationDateFilter\x12\x65\n!application_outcome_notes_filters\x18\x0b \x03(\x0b\x32:.google.cloud.talent.v4beta1.ApplicationOutcomeNotesFilter\x12R\n\x17\x61pplication_job_filters\x18\r \x03(\x0b\x32\x31.google.cloud.talent.v4beta1.ApplicationJobFilter\x12\x1f\n\x17\x63ustom_attribute_filter\x18\x0f \x01(\t\x12\x63\n\x1d\x63\x61ndidate_availability_filter\x18\x10 \x01(\x0b\x32\x38.google.cloud.talent.v4beta1.CandidateAvailabilityFilterB\x02\x18\x01\x12M\n\x14\x61vailability_filters\x18\x12 \x03(\x0b\x32/.google.cloud.talent.v4beta1.AvailabilityFilter\x12J\n\x13person_name_filters\x18\x11 \x03(\x0b\x32-.google.cloud.talent.v4beta1.PersonNameFilter"\xdf\x02\n\x0eLocationFilter\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x0bregion_code\x18\x02 \x01(\t\x12$\n\x07lat_lng\x18\x03 \x01(\x0b\x32\x13.google.type.LatLng\x12\x19\n\x11\x64istance_in_miles\x18\x04 \x01(\x01\x12\x61\n\x16telecommute_preference\x18\x05 \x01(\x0e\x32\x41.google.cloud.talent.v4beta1.LocationFilter.TelecommutePreference\x12\x0f\n\x07negated\x18\x06 \x01(\x08"r\n\x15TelecommutePreference\x12&\n"TELECOMMUTE_PREFERENCE_UNSPECIFIED\x10\x00\x12\x18\n\x14TELECOMMUTE_EXCLUDED\x10\x01\x12\x17\n\x13TELECOMMUTE_ALLOWED\x10\x02"\xca\x03\n\x12\x43ompensationFilter\x12M\n\x04type\x18\x01 \x01(\x0e\x32:.google.cloud.talent.v4beta1.CompensationFilter.FilterTypeB\x03\xe0\x41\x02\x12R\n\x05units\x18\x02 \x03(\x0e\x32>.google.cloud.talent.v4beta1.CompensationInfo.CompensationUnitB\x03\xe0\x41\x02\x12N\n\x05range\x18\x03 \x01(\x0b\x32?.google.cloud.talent.v4beta1.CompensationInfo.CompensationRange\x12\x38\n0include_jobs_with_unspecified_compensation_range\x18\x04 \x01(\x08"\x86\x01\n\nFilterType\x12\x1b\n\x17\x46ILTER_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tUNIT_ONLY\x10\x01\x12\x13\n\x0fUNIT_AND_AMOUNT\x10\x02\x12\x1a\n\x16\x41NNUALIZED_BASE_AMOUNT\x10\x03\x12\x1b\n\x17\x41NNUALIZED_TOTAL_AMOUNT\x10\x04"\xcb\x03\n\rCommuteFilter\x12G\n\x0e\x63ommute_method\x18\x01 \x01(\x0e\x32*.google.cloud.talent.v4beta1.CommuteMethodB\x03\xe0\x41\x02\x12\x33\n\x11start_coordinates\x18\x02 \x01(\x0b\x32\x13.google.type.LatLngB\x03\xe0\x41\x02\x12\x37\n\x0ftravel_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x03\xe0\x41\x02\x12!\n\x19\x61llow_imprecise_addresses\x18\x04 \x01(\x08\x12N\n\x0croad_traffic\x18\x05 \x01(\x0e\x32\x36.google.cloud.talent.v4beta1.CommuteFilter.RoadTrafficH\x00\x12\x30\n\x0e\x64\x65parture_time\x18\x06 \x01(\x0b\x32\x16.google.type.TimeOfDayH\x00"L\n\x0bRoadTraffic\x12\x1c\n\x18ROAD_TRAFFIC_UNSPECIFIED\x10\x00\x12\x10\n\x0cTRAFFIC_FREE\x10\x01\x12\r\n\tBUSY_HOUR\x10\x02\x42\x10\n\x0etraffic_option"9\n\x0eJobTitleFilter\x12\x16\n\tjob_title\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x0f\n\x07negated\x18\x02 \x01(\x08"2\n\x0bSkillFilter\x12\x12\n\x05skill\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x0f\n\x07negated\x18\x02 \x01(\x08"\xa6\x02\n\x0e\x45mployerFilter\x12\x15\n\x08\x65mployer\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12L\n\x04mode\x18\x02 \x01(\x0e\x32>.google.cloud.talent.v4beta1.EmployerFilter.EmployerFilterMode\x12\x0f\n\x07negated\x18\x03 \x01(\x08"\x9d\x01\n\x12\x45mployerFilterMode\x12$\n EMPLOYER_FILTER_MODE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x41LL_EMPLOYMENT_RECORDS\x10\x01\x12#\n\x1f\x43URRENT_EMPLOYMENT_RECORDS_ONLY\x10\x02\x12 \n\x1cPAST_EMPLOYMENT_RECORDS_ONLY\x10\x03"\x88\x01\n\x0f\x45\x64ucationFilter\x12\x0e\n\x06school\x18\x01 \x01(\t\x12\x16\n\x0e\x66ield_of_study\x18\x02 \x01(\t\x12<\n\x0b\x64\x65gree_type\x18\x03 \x01(\x0e\x32\'.google.cloud.talent.v4beta1.DegreeType\x12\x0f\n\x07negated\x18\x06 \x01(\x08"|\n\x14WorkExperienceFilter\x12\x31\n\x0emin_experience\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x31\n\x0emax_experience\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration"c\n\x15\x41pplicationDateFilter\x12%\n\nstart_date\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12#\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x11.google.type.Date"L\n\x1d\x41pplicationOutcomeNotesFilter\x12\x1a\n\routcome_notes\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x0f\n\x07negated\x18\x02 \x01(\x08"V\n\x14\x41pplicationJobFilter\x12\x1a\n\x12job_requisition_id\x18\x02 \x01(\t\x12\x11\n\tjob_title\x18\x03 \x01(\t\x12\x0f\n\x07negated\x18\x04 \x01(\x08"\xfc\x01\n\nTimeFilter\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\ntime_field\x18\x03 \x01(\x0e\x32\x31.google.cloud.talent.v4beta1.TimeFilter.TimeField"I\n\tTimeField\x12\x1a\n\x16TIME_FIELD_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x43REATE_TIME\x10\x01\x12\x0f\n\x0bUPDATE_TIME\x10\x02"2\n\x1b\x43\x61ndidateAvailabilityFilter\x12\x0f\n\x07negated\x18\x01 \x01(\x08:\x02\x18\x01"\xb6\x01\n\x12\x41vailabilityFilter\x12M\n\x0bsignal_type\x18\x01 \x01(\x0e\x32\x33.google.cloud.talent.v4beta1.AvailabilitySignalTypeB\x03\xe0\x41\x02\x12?\n\x05range\x18\x02 \x01(\x0b\x32+.google.cloud.talent.v4beta1.TimestampRangeB\x03\xe0\x41\x02\x12\x10\n\x08required\x18\x03 \x01(\x08",\n\x10PersonNameFilter\x12\x18\n\x0bperson_name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42z\n\x1f\x63om.google.cloud.talent.v4beta1B\x0c\x46iltersProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,
        google_dot_type_dot_date__pb2.DESCRIPTOR,
        google_dot_type_dot_latlng__pb2.DESCRIPTOR,
        google_dot_type_dot_timeofday__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_LOCATIONFILTER_TELECOMMUTEPREFERENCE = _descriptor.EnumDescriptor(
    name="TelecommutePreference",
    full_name="google.cloud.talent.v4beta1.LocationFilter.TelecommutePreference",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TELECOMMUTE_PREFERENCE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TELECOMMUTE_EXCLUDED",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TELECOMMUTE_ALLOWED",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2426,
    serialized_end=2540,
)
_sym_db.RegisterEnumDescriptor(_LOCATIONFILTER_TELECOMMUTEPREFERENCE)

_COMPENSATIONFILTER_FILTERTYPE = _descriptor.EnumDescriptor(
    name="FilterType",
    full_name="google.cloud.talent.v4beta1.CompensationFilter.FilterType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="FILTER_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="UNIT_ONLY", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="UNIT_AND_AMOUNT",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ANNUALIZED_BASE_AMOUNT",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ANNUALIZED_TOTAL_AMOUNT",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2867,
    serialized_end=3001,
)
_sym_db.RegisterEnumDescriptor(_COMPENSATIONFILTER_FILTERTYPE)

_COMMUTEFILTER_ROADTRAFFIC = _descriptor.EnumDescriptor(
    name="RoadTraffic",
    full_name="google.cloud.talent.v4beta1.CommuteFilter.RoadTraffic",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ROAD_TRAFFIC_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TRAFFIC_FREE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BUSY_HOUR", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3369,
    serialized_end=3445,
)
_sym_db.RegisterEnumDescriptor(_COMMUTEFILTER_ROADTRAFFIC)

_EMPLOYERFILTER_EMPLOYERFILTERMODE = _descriptor.EnumDescriptor(
    name="EmployerFilterMode",
    full_name="google.cloud.talent.v4beta1.EmployerFilter.EmployerFilterMode",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="EMPLOYER_FILTER_MODE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ALL_EMPLOYMENT_RECORDS",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="CURRENT_EMPLOYMENT_RECORDS_ONLY",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="PAST_EMPLOYMENT_RECORDS_ONLY",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3714,
    serialized_end=3871,
)
_sym_db.RegisterEnumDescriptor(_EMPLOYERFILTER_EMPLOYERFILTERMODE)

_TIMEFILTER_TIMEFIELD = _descriptor.EnumDescriptor(
    name="TimeField",
    full_name="google.cloud.talent.v4beta1.TimeFilter.TimeField",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TIME_FIELD_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="CREATE_TIME", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="UPDATE_TIME", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4585,
    serialized_end=4658,
)
_sym_db.RegisterEnumDescriptor(_TIMEFILTER_TIMEFIELD)


_JOBQUERY = _descriptor.Descriptor(
    name="JobQuery",
    full_name="google.cloud.talent.v4beta1.JobQuery",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="google.cloud.talent.v4beta1.JobQuery.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="query_language_code",
            full_name="google.cloud.talent.v4beta1.JobQuery.query_language_code",
            index=1,
            number=14,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="companies",
            full_name="google.cloud.talent.v4beta1.JobQuery.companies",
            index=2,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="location_filters",
            full_name="google.cloud.talent.v4beta1.JobQuery.location_filters",
            index=3,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_categories",
            full_name="google.cloud.talent.v4beta1.JobQuery.job_categories",
            index=4,
            number=4,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="commute_filter",
            full_name="google.cloud.talent.v4beta1.JobQuery.commute_filter",
            index=5,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="company_display_names",
            full_name="google.cloud.talent.v4beta1.JobQuery.company_display_names",
            index=6,
            number=6,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="compensation_filter",
            full_name="google.cloud.talent.v4beta1.JobQuery.compensation_filter",
            index=7,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="custom_attribute_filter",
            full_name="google.cloud.talent.v4beta1.JobQuery.custom_attribute_filter",
            index=8,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="disable_spell_check",
            full_name="google.cloud.talent.v4beta1.JobQuery.disable_spell_check",
            index=9,
            number=9,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="employment_types",
            full_name="google.cloud.talent.v4beta1.JobQuery.employment_types",
            index=10,
            number=10,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="language_codes",
            full_name="google.cloud.talent.v4beta1.JobQuery.language_codes",
            index=11,
            number=11,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="publish_time_range",
            full_name="google.cloud.talent.v4beta1.JobQuery.publish_time_range",
            index=12,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="excluded_jobs",
            full_name="google.cloud.talent.v4beta1.JobQuery.excluded_jobs",
            index=13,
            number=13,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=402,
    serialized_end=1042,
)


_PROFILEQUERY = _descriptor.Descriptor(
    name="ProfileQuery",
    full_name="google.cloud.talent.v4beta1.ProfileQuery",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="location_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.location_filters",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_title_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.job_title_filters",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="employer_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.employer_filters",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="education_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.education_filters",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="skill_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.skill_filters",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="work_experience_filter",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.work_experience_filter",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="time_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.time_filters",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="hirable_filter",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.hirable_filter",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="application_date_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.application_date_filters",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="application_outcome_notes_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.application_outcome_notes_filters",
            index=10,
            number=11,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="application_job_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.application_job_filters",
            index=11,
            number=13,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="custom_attribute_filter",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.custom_attribute_filter",
            index=12,
            number=15,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="candidate_availability_filter",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.candidate_availability_filter",
            index=13,
            number=16,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\030\001"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="availability_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.availability_filters",
            index=14,
            number=18,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="person_name_filters",
            full_name="google.cloud.talent.v4beta1.ProfileQuery.person_name_filters",
            index=15,
            number=17,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1045,
    serialized_end=2186,
)


_LOCATIONFILTER = _descriptor.Descriptor(
    name="LocationFilter",
    full_name="google.cloud.talent.v4beta1.LocationFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="address",
            full_name="google.cloud.talent.v4beta1.LocationFilter.address",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="region_code",
            full_name="google.cloud.talent.v4beta1.LocationFilter.region_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="lat_lng",
            full_name="google.cloud.talent.v4beta1.LocationFilter.lat_lng",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="distance_in_miles",
            full_name="google.cloud.talent.v4beta1.LocationFilter.distance_in_miles",
            index=3,
            number=4,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="telecommute_preference",
            full_name="google.cloud.talent.v4beta1.LocationFilter.telecommute_preference",
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="negated",
            full_name="google.cloud.talent.v4beta1.LocationFilter.negated",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_LOCATIONFILTER_TELECOMMUTEPREFERENCE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2189,
    serialized_end=2540,
)


_COMPENSATIONFILTER = _descriptor.Descriptor(
    name="CompensationFilter",
    full_name="google.cloud.talent.v4beta1.CompensationFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.talent.v4beta1.CompensationFilter.type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="units",
            full_name="google.cloud.talent.v4beta1.CompensationFilter.units",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="range",
            full_name="google.cloud.talent.v4beta1.CompensationFilter.range",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="include_jobs_with_unspecified_compensation_range",
            full_name="google.cloud.talent.v4beta1.CompensationFilter.include_jobs_with_unspecified_compensation_range",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_COMPENSATIONFILTER_FILTERTYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2543,
    serialized_end=3001,
)


_COMMUTEFILTER = _descriptor.Descriptor(
    name="CommuteFilter",
    full_name="google.cloud.talent.v4beta1.CommuteFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="commute_method",
            full_name="google.cloud.talent.v4beta1.CommuteFilter.commute_method",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="start_coordinates",
            full_name="google.cloud.talent.v4beta1.CommuteFilter.start_coordinates",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="travel_duration",
            full_name="google.cloud.talent.v4beta1.CommuteFilter.travel_duration",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="allow_imprecise_addresses",
            full_name="google.cloud.talent.v4beta1.CommuteFilter.allow_imprecise_addresses",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="road_traffic",
            full_name="google.cloud.talent.v4beta1.CommuteFilter.road_traffic",
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="departure_time",
            full_name="google.cloud.talent.v4beta1.CommuteFilter.departure_time",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_COMMUTEFILTER_ROADTRAFFIC],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="traffic_option",
            full_name="google.cloud.talent.v4beta1.CommuteFilter.traffic_option",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=3004,
    serialized_end=3463,
)


_JOBTITLEFILTER = _descriptor.Descriptor(
    name="JobTitleFilter",
    full_name="google.cloud.talent.v4beta1.JobTitleFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="job_title",
            full_name="google.cloud.talent.v4beta1.JobTitleFilter.job_title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="negated",
            full_name="google.cloud.talent.v4beta1.JobTitleFilter.negated",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3465,
    serialized_end=3522,
)


_SKILLFILTER = _descriptor.Descriptor(
    name="SkillFilter",
    full_name="google.cloud.talent.v4beta1.SkillFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="skill",
            full_name="google.cloud.talent.v4beta1.SkillFilter.skill",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="negated",
            full_name="google.cloud.talent.v4beta1.SkillFilter.negated",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3524,
    serialized_end=3574,
)


_EMPLOYERFILTER = _descriptor.Descriptor(
    name="EmployerFilter",
    full_name="google.cloud.talent.v4beta1.EmployerFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="employer",
            full_name="google.cloud.talent.v4beta1.EmployerFilter.employer",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mode",
            full_name="google.cloud.talent.v4beta1.EmployerFilter.mode",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="negated",
            full_name="google.cloud.talent.v4beta1.EmployerFilter.negated",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_EMPLOYERFILTER_EMPLOYERFILTERMODE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3577,
    serialized_end=3871,
)


_EDUCATIONFILTER = _descriptor.Descriptor(
    name="EducationFilter",
    full_name="google.cloud.talent.v4beta1.EducationFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="school",
            full_name="google.cloud.talent.v4beta1.EducationFilter.school",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="field_of_study",
            full_name="google.cloud.talent.v4beta1.EducationFilter.field_of_study",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="degree_type",
            full_name="google.cloud.talent.v4beta1.EducationFilter.degree_type",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="negated",
            full_name="google.cloud.talent.v4beta1.EducationFilter.negated",
            index=3,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3874,
    serialized_end=4010,
)


_WORKEXPERIENCEFILTER = _descriptor.Descriptor(
    name="WorkExperienceFilter",
    full_name="google.cloud.talent.v4beta1.WorkExperienceFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="min_experience",
            full_name="google.cloud.talent.v4beta1.WorkExperienceFilter.min_experience",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="max_experience",
            full_name="google.cloud.talent.v4beta1.WorkExperienceFilter.max_experience",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4012,
    serialized_end=4136,
)


_APPLICATIONDATEFILTER = _descriptor.Descriptor(
    name="ApplicationDateFilter",
    full_name="google.cloud.talent.v4beta1.ApplicationDateFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_date",
            full_name="google.cloud.talent.v4beta1.ApplicationDateFilter.start_date",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_date",
            full_name="google.cloud.talent.v4beta1.ApplicationDateFilter.end_date",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4138,
    serialized_end=4237,
)


_APPLICATIONOUTCOMENOTESFILTER = _descriptor.Descriptor(
    name="ApplicationOutcomeNotesFilter",
    full_name="google.cloud.talent.v4beta1.ApplicationOutcomeNotesFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="outcome_notes",
            full_name="google.cloud.talent.v4beta1.ApplicationOutcomeNotesFilter.outcome_notes",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="negated",
            full_name="google.cloud.talent.v4beta1.ApplicationOutcomeNotesFilter.negated",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4239,
    serialized_end=4315,
)


_APPLICATIONJOBFILTER = _descriptor.Descriptor(
    name="ApplicationJobFilter",
    full_name="google.cloud.talent.v4beta1.ApplicationJobFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="job_requisition_id",
            full_name="google.cloud.talent.v4beta1.ApplicationJobFilter.job_requisition_id",
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_title",
            full_name="google.cloud.talent.v4beta1.ApplicationJobFilter.job_title",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="negated",
            full_name="google.cloud.talent.v4beta1.ApplicationJobFilter.negated",
            index=2,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4317,
    serialized_end=4403,
)


_TIMEFILTER = _descriptor.Descriptor(
    name="TimeFilter",
    full_name="google.cloud.talent.v4beta1.TimeFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="google.cloud.talent.v4beta1.TimeFilter.start_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.talent.v4beta1.TimeFilter.end_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="time_field",
            full_name="google.cloud.talent.v4beta1.TimeFilter.time_field",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_TIMEFILTER_TIMEFIELD],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4406,
    serialized_end=4658,
)


_CANDIDATEAVAILABILITYFILTER = _descriptor.Descriptor(
    name="CandidateAvailabilityFilter",
    full_name="google.cloud.talent.v4beta1.CandidateAvailabilityFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="negated",
            full_name="google.cloud.talent.v4beta1.CandidateAvailabilityFilter.negated",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("\030\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4660,
    serialized_end=4710,
)


_AVAILABILITYFILTER = _descriptor.Descriptor(
    name="AvailabilityFilter",
    full_name="google.cloud.talent.v4beta1.AvailabilityFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="signal_type",
            full_name="google.cloud.talent.v4beta1.AvailabilityFilter.signal_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="range",
            full_name="google.cloud.talent.v4beta1.AvailabilityFilter.range",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="required",
            full_name="google.cloud.talent.v4beta1.AvailabilityFilter.required",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4713,
    serialized_end=4895,
)


_PERSONNAMEFILTER = _descriptor.Descriptor(
    name="PersonNameFilter",
    full_name="google.cloud.talent.v4beta1.PersonNameFilter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="person_name",
            full_name="google.cloud.talent.v4beta1.PersonNameFilter.person_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4897,
    serialized_end=4941,
)

_JOBQUERY.fields_by_name["location_filters"].message_type = _LOCATIONFILTER
_JOBQUERY.fields_by_name[
    "job_categories"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._JOBCATEGORY
)
_JOBQUERY.fields_by_name["commute_filter"].message_type = _COMMUTEFILTER
_JOBQUERY.fields_by_name["compensation_filter"].message_type = _COMPENSATIONFILTER
_JOBQUERY.fields_by_name[
    "employment_types"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._EMPLOYMENTTYPE
)
_JOBQUERY.fields_by_name[
    "publish_time_range"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._TIMESTAMPRANGE
)
_PROFILEQUERY.fields_by_name["location_filters"].message_type = _LOCATIONFILTER
_PROFILEQUERY.fields_by_name["job_title_filters"].message_type = _JOBTITLEFILTER
_PROFILEQUERY.fields_by_name["employer_filters"].message_type = _EMPLOYERFILTER
_PROFILEQUERY.fields_by_name["education_filters"].message_type = _EDUCATIONFILTER
_PROFILEQUERY.fields_by_name["skill_filters"].message_type = _SKILLFILTER
_PROFILEQUERY.fields_by_name[
    "work_experience_filter"
].message_type = _WORKEXPERIENCEFILTER
_PROFILEQUERY.fields_by_name["time_filters"].message_type = _TIMEFILTER
_PROFILEQUERY.fields_by_name[
    "hirable_filter"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PROFILEQUERY.fields_by_name[
    "application_date_filters"
].message_type = _APPLICATIONDATEFILTER
_PROFILEQUERY.fields_by_name[
    "application_outcome_notes_filters"
].message_type = _APPLICATIONOUTCOMENOTESFILTER
_PROFILEQUERY.fields_by_name[
    "application_job_filters"
].message_type = _APPLICATIONJOBFILTER
_PROFILEQUERY.fields_by_name[
    "candidate_availability_filter"
].message_type = _CANDIDATEAVAILABILITYFILTER
_PROFILEQUERY.fields_by_name["availability_filters"].message_type = _AVAILABILITYFILTER
_PROFILEQUERY.fields_by_name["person_name_filters"].message_type = _PERSONNAMEFILTER
_LOCATIONFILTER.fields_by_name[
    "lat_lng"
].message_type = google_dot_type_dot_latlng__pb2._LATLNG
_LOCATIONFILTER.fields_by_name[
    "telecommute_preference"
].enum_type = _LOCATIONFILTER_TELECOMMUTEPREFERENCE
_LOCATIONFILTER_TELECOMMUTEPREFERENCE.containing_type = _LOCATIONFILTER
_COMPENSATIONFILTER.fields_by_name["type"].enum_type = _COMPENSATIONFILTER_FILTERTYPE
_COMPENSATIONFILTER.fields_by_name[
    "units"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._COMPENSATIONINFO_COMPENSATIONUNIT
)
_COMPENSATIONFILTER.fields_by_name[
    "range"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._COMPENSATIONINFO_COMPENSATIONRANGE
)
_COMPENSATIONFILTER_FILTERTYPE.containing_type = _COMPENSATIONFILTER
_COMMUTEFILTER.fields_by_name[
    "commute_method"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._COMMUTEMETHOD
)
_COMMUTEFILTER.fields_by_name[
    "start_coordinates"
].message_type = google_dot_type_dot_latlng__pb2._LATLNG
_COMMUTEFILTER.fields_by_name[
    "travel_duration"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMUTEFILTER.fields_by_name["road_traffic"].enum_type = _COMMUTEFILTER_ROADTRAFFIC
_COMMUTEFILTER.fields_by_name[
    "departure_time"
].message_type = google_dot_type_dot_timeofday__pb2._TIMEOFDAY
_COMMUTEFILTER_ROADTRAFFIC.containing_type = _COMMUTEFILTER
_COMMUTEFILTER.oneofs_by_name["traffic_option"].fields.append(
    _COMMUTEFILTER.fields_by_name["road_traffic"]
)
_COMMUTEFILTER.fields_by_name[
    "road_traffic"
].containing_oneof = _COMMUTEFILTER.oneofs_by_name["traffic_option"]
_COMMUTEFILTER.oneofs_by_name["traffic_option"].fields.append(
    _COMMUTEFILTER.fields_by_name["departure_time"]
)
_COMMUTEFILTER.fields_by_name[
    "departure_time"
].containing_oneof = _COMMUTEFILTER.oneofs_by_name["traffic_option"]
_EMPLOYERFILTER.fields_by_name["mode"].enum_type = _EMPLOYERFILTER_EMPLOYERFILTERMODE
_EMPLOYERFILTER_EMPLOYERFILTERMODE.containing_type = _EMPLOYERFILTER
_EDUCATIONFILTER.fields_by_name[
    "degree_type"
].enum_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._DEGREETYPE
_WORKEXPERIENCEFILTER.fields_by_name[
    "min_experience"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WORKEXPERIENCEFILTER.fields_by_name[
    "max_experience"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_APPLICATIONDATEFILTER.fields_by_name[
    "start_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_APPLICATIONDATEFILTER.fields_by_name[
    "end_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_TIMEFILTER.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMEFILTER.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMEFILTER.fields_by_name["time_field"].enum_type = _TIMEFILTER_TIMEFIELD
_TIMEFILTER_TIMEFIELD.containing_type = _TIMEFILTER
_AVAILABILITYFILTER.fields_by_name[
    "signal_type"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._AVAILABILITYSIGNALTYPE
)
_AVAILABILITYFILTER.fields_by_name[
    "range"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._TIMESTAMPRANGE
)
DESCRIPTOR.message_types_by_name["JobQuery"] = _JOBQUERY
DESCRIPTOR.message_types_by_name["ProfileQuery"] = _PROFILEQUERY
DESCRIPTOR.message_types_by_name["LocationFilter"] = _LOCATIONFILTER
DESCRIPTOR.message_types_by_name["CompensationFilter"] = _COMPENSATIONFILTER
DESCRIPTOR.message_types_by_name["CommuteFilter"] = _COMMUTEFILTER
DESCRIPTOR.message_types_by_name["JobTitleFilter"] = _JOBTITLEFILTER
DESCRIPTOR.message_types_by_name["SkillFilter"] = _SKILLFILTER
DESCRIPTOR.message_types_by_name["EmployerFilter"] = _EMPLOYERFILTER
DESCRIPTOR.message_types_by_name["EducationFilter"] = _EDUCATIONFILTER
DESCRIPTOR.message_types_by_name["WorkExperienceFilter"] = _WORKEXPERIENCEFILTER
DESCRIPTOR.message_types_by_name["ApplicationDateFilter"] = _APPLICATIONDATEFILTER
DESCRIPTOR.message_types_by_name[
    "ApplicationOutcomeNotesFilter"
] = _APPLICATIONOUTCOMENOTESFILTER
DESCRIPTOR.message_types_by_name["ApplicationJobFilter"] = _APPLICATIONJOBFILTER
DESCRIPTOR.message_types_by_name["TimeFilter"] = _TIMEFILTER
DESCRIPTOR.message_types_by_name[
    "CandidateAvailabilityFilter"
] = _CANDIDATEAVAILABILITYFILTER
DESCRIPTOR.message_types_by_name["AvailabilityFilter"] = _AVAILABILITYFILTER
DESCRIPTOR.message_types_by_name["PersonNameFilter"] = _PERSONNAMEFILTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JobQuery = _reflection.GeneratedProtocolMessageType(
    "JobQuery",
    (_message.Message,),
    dict(
        DESCRIPTOR=_JOBQUERY,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""The query required to perform a search query.
  
  
  Attributes:
      query:
          The query string that matches against the job title,
          description, and location fields.  The maximum number of
          allowed characters is 255.
      query_language_code:
          The language code of
          [query][google.cloud.talent.v4beta1.JobQuery.query]. For
          example, "en-US". This field helps to better interpret the
          query.  If a value isn't specified, the query language code is
          automatically detected, which may not be accurate.  Language
          code should be in BCP-47 format, such as "en-US" or "sr-Latn".
          For more information, see `Tags for Identifying Languages
          <https://tools.ietf.org/html/bcp47>`__.
      companies:
          This filter specifies the company entities to search against.
          If a value isn't specified, jobs are searched for against all
          companies.  If multiple values are specified, jobs are
          searched against the companies specified.  The format is "proj
          ects/{project\_id}/tenants/{tenant\_id}/companies/{company\_id
          }". For example, "projects/foo/tenants/bar/companies/baz".  If
          tenant id is unspecified, the default tenant is used. For
          example, "projects/foo/companies/bar".  At most 20 company
          filters are allowed.
      location_filters:
          The location filter specifies geo-regions containing the jobs
          to search against. See
          [LocationFilter][google.cloud.talent.v4beta1.LocationFilter]
          for more information.  If a location value isn't specified,
          jobs fitting the other search criteria are retrieved
          regardless of where they're located.  If multiple values are
          specified, jobs are retrieved from any of the specified
          locations. If different values are specified for the [Location
          Filter.distance\_in\_miles][google.cloud.talent.v4beta1.Locati
          onFilter.distance\_in\_miles] parameter, the maximum provided
          distance is used for all locations.  At most 5 location
          filters are allowed.
      job_categories:
          The category filter specifies the categories of jobs to search
          against. See
          [JobCategory][google.cloud.talent.v4beta1.JobCategory] for
          more information.  If a value isn't specified, jobs from any
          category are searched against.  If multiple values are
          specified, jobs from any of the specified categories are
          searched against.
      commute_filter:
          Allows filtering jobs by commute time with different travel
          methods (for example, driving or public transit).  Note: This
          only works when you specify a
          [CommuteMethod][google.cloud.talent.v4beta1.CommuteMethod]. In
          this case, [location\_filters][google.cloud.talent.v4beta1.Job
          Query.location\_filters] is ignored.  Currently we don't
          support sorting by commute time.
      company_display_names:
          This filter specifies the exact company [Company.display\_name
          ][google.cloud.talent.v4beta1.Company.display\_name] of the
          jobs to search against.  If a value isn't specified, jobs
          within the search results are associated with any company.  If
          multiple values are specified, jobs within the search results
          may be associated with any of the specified companies.  At
          most 20 company display name filters are allowed.
      compensation_filter:
          This search filter is applied only to [Job.compensation\_info]
          [google.cloud.talent.v4beta1.Job.compensation\_info]. For
          example, if the filter is specified as "Hourly job with per-
          hour compensation > $15", only jobs meeting these criteria are
          searched. If a filter isn't defined, all open jobs are
          searched.
      custom_attribute_filter:
          This filter specifies a structured syntax to match against the
          [Job.custom\_attributes][google.cloud.talent.v4beta1.Job.custo
          m\_attributes] marked as ``filterable``.  The syntax for this
          expression is a subset of SQL syntax.  Supported operators
          are: ``=``, ``!=``, ``<``, ``<=``, ``>``, and ``>=`` where the
          left of the operator is a custom field key and the right of
          the operator is a number or a quoted string. You must escape
          backslash (\\) and quote (") characters.  Supported functions
          are ``LOWER([field_name])`` to perform a case insensitive
          match and ``EMPTY([field_name])`` to filter on the existence
          of a key.  Boolean expressions (AND/OR/NOT) are supported up
          to 3 levels of nesting (for example, "((A AND B AND C) OR NOT
          D) AND E"), a maximum of 100 comparisons or functions are
          allowed in the expression. The expression must be < 6000 bytes
          in length.  Sample Query: ``(LOWER(driving_license)="class
          \"a\"" OR EMPTY(driving_license)) AND driving_years > 10``
      disable_spell_check:
          This flag controls the spell-check feature. If false, the
          service attempts to correct a misspelled query, for example,
          "enginee" is corrected to "engineer".  Defaults to false: a
          spell check is performed.
      employment_types:
          The employment type filter specifies the employment type of
          jobs to search against, such as [EmploymentType.FULL\_TIME][go
          ogle.cloud.talent.v4beta1.EmploymentType.FULL\_TIME].  If a
          value isn't specified, jobs in the search results includes any
          employment type.  If multiple values are specified, jobs in
          the search results include any of the specified employment
          types.
      language_codes:
          This filter specifies the locale of jobs to search against,
          for example, "en-US".  If a value isn't specified, the search
          results can contain jobs in any locale.  Language codes should
          be in BCP-47 format, such as "en-US" or "sr-Latn". For more
          information, see `Tags for Identifying Languages
          <https://tools.ietf.org/html/bcp47>`__.  At most 10 language
          code filters are allowed.
      publish_time_range:
          Jobs published within a range specified by this filter are
          searched against.
      excluded_jobs:
          This filter specifies a list of job names to be excluded
          during search.  At most 400 excluded job names are allowed.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.JobQuery)
    ),
)
_sym_db.RegisterMessage(JobQuery)

ProfileQuery = _reflection.GeneratedProtocolMessageType(
    "ProfileQuery",
    (_message.Message,),
    dict(
        DESCRIPTOR=_PROFILEQUERY,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Filters to apply when performing the search query.
  
  
  Attributes:
      query:
          Keywords to match any text fields of profiles.  For example,
          "software engineer in Palo Alto".
      location_filters:
          The location filter specifies geo-regions containing the
          profiles to search against.  One of [LocationFilter.address][g
          oogle.cloud.talent.v4beta1.LocationFilter.address] or [Locatio
          nFilter.lat\_lng][google.cloud.talent.v4beta1.LocationFilter.l
          at\_lng] must be provided or an error is thrown. If both [Loca
          tionFilter.address][google.cloud.talent.v4beta1.LocationFilter
          .address] and [LocationFilter.lat\_lng][google.cloud.talent.v4
          beta1.LocationFilter.lat\_lng] are provided, an error is
          thrown.  The following logic is used to determine which
          locations in the profile to filter against:  1. All of the
          profile's geocoded    [Profile.addresses][google.cloud.talent.
          v4beta1.Profile.addresses]    where
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] is
          PERSONAL and
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          is    true.  2. If the above set of locations is empty, all of
          the profile's geocoded    [Profile.addresses][google.cloud.tal
          ent.v4beta1.Profile.addresses]    where
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] is
          CONTACT\_INFO\_USAGE\_UNSPECIFIED and
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          is    true.  3. If the above set of locations is empty, all of
          the profile's geocoded    [Profile.addresses][google.cloud.tal
          ent.v4beta1.Profile.addresses]    where
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] is
          PERSONAL or CONTACT\_INFO\_USAGE\_UNSPECIFIED and
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          is not    set.  This means that any profiles without any [Prof
          ile.addresses][google.cloud.talent.v4beta1.Profile.addresses]
          that match any of the above criteria will not be included in a
          search with location filter. Furthermore, any [Profile.address
          es][google.cloud.talent.v4beta1.Profile.addresses] where
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] is
          WORK or SCHOOL or where
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          is false are not considered for location filter.  If a
          location filter isn't specified, profiles fitting the other
          search criteria are retrieved regardless of where they're
          located.  If [LocationFilter.negated][google.cloud.talent.v4be
          ta1.LocationFilter.negated] is specified, the result doesn't
          contain profiles from that location.  If [LocationFilter.addre
          ss][google.cloud.talent.v4beta1.LocationFilter.address] is
          provided, the [LocationType][google.cloud.talent.v4beta1.Locat
          ion.LocationType], center point (latitude and longitude), and
          radius are automatically detected by the Google Maps Geocoding
          API and included as well. If [LocationFilter.address][google.c
          loud.talent.v4beta1.LocationFilter.address] cannot be
          geocoded, the filter falls back to keyword search.  If the
          detected [LocationType][google.cloud.talent.v4beta1.Location.L
          ocationType] is [LocationType.SUB\_ADMINISTRATIVE\_AREA][googl
          e.cloud.talent.v4beta1.Location.LocationType.SUB\_ADMINISTRATI
          VE\_AREA], [LocationType.ADMINISTRATIVE\_AREA][google.cloud.ta
          lent.v4beta1.Location.LocationType.ADMINISTRATIVE\_AREA], or [
          LocationType.COUNTRY][google.cloud.talent.v4beta1.Location.Loc
          ationType.COUNTRY], the filter is performed against the
          detected location name (using exact text matching). Otherwise,
          the filter is performed against the detected center point and
          a radius of detected location radius + [LocationFilter.distanc
          e\_in\_miles][google.cloud.talent.v4beta1.LocationFilter.dista
          nce\_in\_miles].  If [LocationFilter.address][google.cloud.tal
          ent.v4beta1.LocationFilter.address] is provided, [LocationFilt
          er.distance\_in\_miles][google.cloud.talent.v4beta1.LocationFi
          lter.distance\_in\_miles] is the additional radius on top of
          the radius of the location geocoded from [LocationFilter.addre
          ss][google.cloud.talent.v4beta1.LocationFilter.address]. If [L
          ocationFilter.lat\_lng][google.cloud.talent.v4beta1.LocationFi
          lter.lat\_lng] is provided, [LocationFilter.distance\_in\_mile
          s][google.cloud.talent.v4beta1.LocationFilter.distance\_in\_mi
          les] is the only radius that is used.  [LocationFilter.distanc
          e\_in\_miles][google.cloud.talent.v4beta1.LocationFilter.dista
          nce\_in\_miles] is 10 by default. Note that the value of [Loca
          tionFilter.distance\_in\_miles][google.cloud.talent.v4beta1.Lo
          cationFilter.distance\_in\_miles] is 0 if it is unset, so the
          server does not differentiate [LocationFilter.distance\_in\_mi
          les][google.cloud.talent.v4beta1.LocationFilter.distance\_in\_
          miles] that is explicitly set to 0 and [LocationFilter.distanc
          e\_in\_miles][google.cloud.talent.v4beta1.LocationFilter.dista
          nce\_in\_miles] that is not set. Which means that if [Location
          Filter.distance\_in\_miles][google.cloud.talent.v4beta1.Locati
          onFilter.distance\_in\_miles] is explicitly set to 0, the
          server will use the default value of [LocationFilter.distance\
          _in\_miles][google.cloud.talent.v4beta1.LocationFilter.distanc
          e\_in\_miles] which is 10. To work around this and effectively
          set [LocationFilter.distance\_in\_miles][google.cloud.talent.v
          4beta1.LocationFilter.distance\_in\_miles] to 0, we recommend
          setting [LocationFilter.distance\_in\_miles][google.cloud.tale
          nt.v4beta1.LocationFilter.distance\_in\_miles] to a very small
          decimal number (such as 0.00001).  If [LocationFilter.distance
          \_in\_miles][google.cloud.talent.v4beta1.LocationFilter.distan
          ce\_in\_miles] is negative, an error is thrown.
      job_title_filters:
          Job title filter specifies job titles of profiles to match on.
          If a job title isn't specified, profiles with any titles are
          retrieved.  If multiple values are specified, profiles are
          retrieved with any of the specified job titles.  If [JobTitleF
          ilter.negated][google.cloud.talent.v4beta1.JobTitleFilter.nega
          ted] is specified, the result won't contain profiles with the
          job titles.  For example, search for profiles with a job title
          "Product Manager".
      employer_filters:
          Employer filter specifies employers of profiles to match on.
          If an employer filter isn't specified, profiles with any
          employers are retrieved.  If multiple employer filters are
          specified, profiles with any matching employers are retrieved.
          If [EmployerFilter.negated][google.cloud.talent.v4beta1.Employ
          erFilter.negated] is specified, the result won't contain
          profiles that match the employers.  For example, search for
          profiles that have working experience at "Google LLC".
      education_filters:
          Education filter specifies education of profiles to match on.
          If an education filter isn't specified, profiles with any
          education are retrieved.  If multiple education filters are
          specified, profiles that match any education filters are
          retrieved.  If [EducationFilter.negated][google.cloud.talent.v
          4beta1.EducationFilter.negated] is specified, the result won't
          contain profiles that match the educations.  For example,
          search for profiles with a master degree.
      skill_filters:
          Skill filter specifies skill of profiles to match on.  If a
          skill filter isn't specified, profiles with any skills are
          retrieved.  If multiple skill filters are specified, profiles
          that match any skill filters are retrieved.  If [SkillFilter.n
          egated][google.cloud.talent.v4beta1.SkillFilter.negated] is
          specified, the result won't contain profiles that match the
          skills.  For example, search for profiles that have "Java" and
          "Python" in skill list.
      work_experience_filter:
          Work experience filter specifies the total working experience
          of profiles to match on.  If a work experience filter isn't
          specified, profiles with any professional experience are
          retrieved.  If multiple work experience filters are specified,
          profiles that match any work experience filters are retrieved.
          For example, search for profiles with 10 years of work
          experience.
      time_filters:
          Time filter specifies the create/update timestamp of the
          profiles to match on.  For example, search for profiles
          created since "2018-1-1".
      hirable_filter:
          The hirable filter specifies the profile's hirable status to
          match on.
      application_date_filters:
          The application date filters specify application date ranges
          to match on.
      application_outcome_notes_filters:
          The application outcome notes filters specify the notes for
          the outcome of the job application.
      application_job_filters:
          The application job filters specify the job applied for in the
          application.
      custom_attribute_filter:
          This filter specifies a structured syntax to match against the
          [Profile.custom\_attributes][google.cloud.talent.v4beta1.Profi
          le.custom\_attributes] that are marked as ``filterable``.  The
          syntax for this expression is a subset of Google SQL syntax.
          String custom attributes: supported operators are =, != where
          the left of the operator is a custom field key and the right
          of the operator is a string (surrounded by quotes) value.
          Numeric custom attributes: Supported operators are '>', '<' or
          '=' operators where the left of the operator is a custom field
          key and the right of the operator is a numeric value.
          Supported functions are LOWER() to perform case insensitive
          match and EMPTY() to filter on the existence of a key.
          Boolean expressions (AND/OR/NOT) are supported up to 3 levels
          of nesting (for example "((A AND B AND C) OR NOT D) AND E"),
          and there can be a maximum of 50 comparisons/functions in the
          expression. The expression must be < 2000 characters in
          length.  Sample Query: (key1 = "TEST" OR LOWER(key1)="test" OR
          NOT EMPTY(key1))
      candidate_availability_filter:
          Deprecated. Use availability\_filters instead.  The candidate
          availability filter which filters based on availability
          signals.  Signal 1: Number of days since most recent job
          application. See [Availability.JobApplicationAvailabilitySigna
          l][google.cloud.talent.v4beta1.Availability.JobApplicationAvai
          labilitySignal] for the details of this signal.  Signal 2:
          Number of days since last profile update. See [Availability.Pr
          ofileUpdateAvailabilitySignal][google.cloud.talent.v4beta1.Ava
          ilability.ProfileUpdateAvailabilitySignal] for the details of
          this signal.  The candidate availability filter helps a
          recruiter understand if a specific candidate is likely to be
          actively seeking new job opportunities based on an aggregated
          set of signals. Specifically, the intent is NOT to indicate
          the candidate's potential qualification / interest / close
          ability for a specific job.
      availability_filters:
          The availability filter which filters based on [Profile.availa
          bility\_signals][google.cloud.talent.v4beta1.Profile.availabil
          ity\_signals].  The availability filter helps a recruiter
          understand if a specific candidate is likely to be actively
          seeking new job opportunities based on an aggregated set of
          signals. Specifically, the intent is NOT to indicate the
          candidate's potential qualification / interest / close ability
          for a specific job.  There can be at most one [AvailabilityFil
          ter][google.cloud.talent.v4beta1.AvailabilityFilter] per [sign
          al\_type][google.cloud.talent.v4beta1.AvailabilityFilter.signa
          l\_type]. If there are multiple [AvailabilityFilter][google.cl
          oud.talent.v4beta1.AvailabilityFilter] for a [signal\_type][go
          ogle.cloud.talent.v4beta1.AvailabilityFilter.signal\_type], an
          error is thrown.
      person_name_filters:
          Person name filter specifies person name of profiles to match
          on.  If multiple person name filters are specified, profiles
          that match any person name filters are retrieved.  For
          example, search for profiles of candidates with name "John
          Smith".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ProfileQuery)
    ),
)
_sym_db.RegisterMessage(ProfileQuery)

LocationFilter = _reflection.GeneratedProtocolMessageType(
    "LocationFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LOCATIONFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Geographic region of the search.
  
  
  Attributes:
      address:
          The address name, such as "Mountain View" or "Bay Area".
      region_code:
          CLDR region code of the country/region of the address. This is
          used to address ambiguity of the user-input location, for
          example, "Liverpool" against "Liverpool, NY, US" or
          "Liverpool, UK".  Set this field to bias location resolution
          toward a specific country or territory. If this field is not
          set, application behavior is biased toward the United States
          by default.  See https://cldr.unicode.org/ and https://www.uni
          code.org/cldr/charts/30/supplemental/territory\_information.ht
          ml for details. Example: "CH" for Switzerland. Note that this
          filter is not applicable for Profile Search related queries.
      lat_lng:
          The latitude and longitude of the geographic center to search
          from. This field is ignored if ``address`` is provided.
      distance_in_miles:
          The distance\_in\_miles is applied when the location being
          searched for is identified as a city or smaller. This field is
          ignored if the location being searched for is a state or
          larger.
      telecommute_preference:
          Allows the client to return jobs without a set location,
          specifically, telecommuting jobs (telecommuting is considered
          by the service as a special location. [Job.posting\_region][go
          ogle.cloud.talent.v4beta1.Job.posting\_region] indicates if a
          job permits telecommuting. If this field is set to [Telecommut
          ePreference.TELECOMMUTE\_ALLOWED][google.cloud.talent.v4beta1.
          LocationFilter.TelecommutePreference.TELECOMMUTE\_ALLOWED],
          telecommuting jobs are searched, and
          [address][google.cloud.talent.v4beta1.LocationFilter.address]
          and [lat\_lng][google.cloud.talent.v4beta1.LocationFilter.lat\
          _lng] are ignored. If not set or set to [TelecommutePreference
          .TELECOMMUTE\_EXCLUDED][google.cloud.talent.v4beta1.LocationFi
          lter.TelecommutePreference.TELECOMMUTE\_EXCLUDED], telecommute
          job are not searched.  This filter can be used by itself to
          search exclusively for telecommuting jobs, or it can be
          combined with another location filter to search for a
          combination of job locations, such as "Mountain View" or
          "telecommuting" jobs. However, when used in combination with
          other location filters, telecommuting jobs can be treated as
          less relevant than other jobs in the search response.  This
          field is only used for job search requests.
      negated:
          Whether to apply negation to the filter so profiles matching
          the filter are excluded.  Currently only supported in profile
          search.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.LocationFilter)
    ),
)
_sym_db.RegisterMessage(LocationFilter)

CompensationFilter = _reflection.GeneratedProtocolMessageType(
    "CompensationFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_COMPENSATIONFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Filter on job compensation type and amount.
  
  
  Attributes:
      type:
          Required. Type of filter.
      units:
          Required. Specify desired ``base compensation entry's`` [Compe
          nsationInfo.CompensationUnit][google.cloud.talent.v4beta1.Comp
          ensationInfo.CompensationUnit].
      range:
          Compensation range.
      include_jobs_with_unspecified_compensation_range:
          If set to true, jobs with unspecified compensation range
          fields are included.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CompensationFilter)
    ),
)
_sym_db.RegisterMessage(CompensationFilter)

CommuteFilter = _reflection.GeneratedProtocolMessageType(
    "CommuteFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_COMMUTEFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Parameters needed for commute search.
  
  
  Attributes:
      commute_method:
          Required. The method of transportation to calculate the
          commute time for.
      start_coordinates:
          Required. The latitude and longitude of the location to
          calculate the commute time from.
      travel_duration:
          Required. The maximum travel time in seconds. The maximum
          allowed value is ``3600s`` (one hour). Format is ``123s``.
      allow_imprecise_addresses:
          If ``true``, jobs without street level addresses may also be
          returned. For city level addresses, the city center is used.
          For state and coarser level addresses, text matching is used.
          If this field is set to ``false`` or isn't specified, only
          jobs that include street level addresses will be returned by
          commute search.
      traffic_option:
          Traffic factor to take into account while searching by
          commute.
      road_traffic:
          Specifies the traffic density to use when calculating commute
          time.
      departure_time:
          The departure time used to calculate traffic impact,
          represented as [google.type.TimeOfDay][google.type.TimeOfDay]
          in local time zone.  Currently traffic model is restricted to
          hour level resolution.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CommuteFilter)
    ),
)
_sym_db.RegisterMessage(CommuteFilter)

JobTitleFilter = _reflection.GeneratedProtocolMessageType(
    "JobTitleFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_JOBTITLEFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Job title of the search.
  
  
  Attributes:
      job_title:
          Required. The job title. For example, "Software engineer", or
          "Product manager".
      negated:
          Whether to apply negation to the filter so profiles matching
          the filter are excluded.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.JobTitleFilter)
    ),
)
_sym_db.RegisterMessage(JobTitleFilter)

SkillFilter = _reflection.GeneratedProtocolMessageType(
    "SkillFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SKILLFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Skill filter of the search.
  
  
  Attributes:
      skill:
          Required. The skill name. For example, "java", "j2ee", and so
          on.
      negated:
          Whether to apply negation to the filter so profiles matching
          the filter are excluded.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SkillFilter)
    ),
)
_sym_db.RegisterMessage(SkillFilter)

EmployerFilter = _reflection.GeneratedProtocolMessageType(
    "EmployerFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EMPLOYERFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Employer filter of the search.
  
  
  Attributes:
      employer:
          Required. The name of the employer, for example "Google",
          "Alphabet".
      mode:
          Define set of [EmploymentRecord][google.cloud.talent.v4beta1.E
          mploymentRecord]s to search against.  Defaults to [EmployerFil
          terMode.ALL\_EMPLOYMENT\_RECORDS][google.cloud.talent.v4beta1.
          EmployerFilter.EmployerFilterMode.ALL\_EMPLOYMENT\_RECORDS].
      negated:
          Whether to apply negation to the filter so profiles matching
          the filter is excluded.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.EmployerFilter)
    ),
)
_sym_db.RegisterMessage(EmployerFilter)

EducationFilter = _reflection.GeneratedProtocolMessageType(
    "EducationFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EDUCATIONFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Education filter of the search.
  
  
  Attributes:
      school:
          The school name. For example "MIT", "University of California,
          Berkeley".
      field_of_study:
          The field of study. This is to search against value provided
          in [Degree.fields\_of\_study][google.cloud.talent.v4beta1.Degr
          ee.fields\_of\_study]. For example "Computer Science",
          "Mathematics".
      degree_type:
          Education degree in ISCED code. Each value in degree covers a
          specific level of education, without any expansion to upper
          nor lower levels of education degree.
      negated:
          Whether to apply negation to the filter so profiles matching
          the filter is excluded.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.EducationFilter)
    ),
)
_sym_db.RegisterMessage(EducationFilter)

WorkExperienceFilter = _reflection.GeneratedProtocolMessageType(
    "WorkExperienceFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_WORKEXPERIENCEFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Work experience filter.
  
  This filter is used to search for profiles with working experience
  length between
  [min\_experience][google.cloud.talent.v4beta1.WorkExperienceFilter.min\_experience]
  and
  [max\_experience][google.cloud.talent.v4beta1.WorkExperienceFilter.max\_experience].
  
  
  Attributes:
      min_experience:
          The minimum duration of the work experience (inclusive).
      max_experience:
          The maximum duration of the work experience (exclusive).
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.WorkExperienceFilter)
    ),
)
_sym_db.RegisterMessage(WorkExperienceFilter)

ApplicationDateFilter = _reflection.GeneratedProtocolMessageType(
    "ApplicationDateFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_APPLICATIONDATEFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Application Date Range Filter.
  
  The API matches profiles with
  [Application.application\_date][google.cloud.talent.v4beta1.Application.application\_date]
  between start date and end date (both boundaries are inclusive). The
  filter is ignored if both
  [start\_date][google.cloud.talent.v4beta1.ApplicationDateFilter.start\_date]
  and
  [end\_date][google.cloud.talent.v4beta1.ApplicationDateFilter.end\_date]
  are missing.
  
  
  Attributes:
      start_date:
          Start date. If it's missing, The API matches profiles with
          application date not after the end date.
      end_date:
          End date. If it's missing, The API matches profiles with
          application date not before the start date.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ApplicationDateFilter)
    ),
)
_sym_db.RegisterMessage(ApplicationDateFilter)

ApplicationOutcomeNotesFilter = _reflection.GeneratedProtocolMessageType(
    "ApplicationOutcomeNotesFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_APPLICATIONOUTCOMENOTESFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Outcome Notes Filter.
  
  
  Attributes:
      outcome_notes:
          Required. User entered or selected outcome reason. The API
          does an exact match on the [Application.outcome\_notes][google
          .cloud.talent.v4beta1.Application.outcome\_notes] in profiles.
      negated:
          If true, The API excludes all candidates with any [Application
          .outcome\_notes][google.cloud.talent.v4beta1.Application.outco
          me\_notes] matching the outcome reason specified in the
          filter.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ApplicationOutcomeNotesFilter)
    ),
)
_sym_db.RegisterMessage(ApplicationOutcomeNotesFilter)

ApplicationJobFilter = _reflection.GeneratedProtocolMessageType(
    "ApplicationJobFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_APPLICATIONJOBFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Filter on the job information of Application.
  
  
  Attributes:
      job_requisition_id:
          The job requisition id in the application. The API does an
          exact match on the [Job.requisition\_id][google.cloud.talent.v
          4beta1.Job.requisition\_id] of
          [Application.job][google.cloud.talent.v4beta1.Application.job]
          in profiles.
      job_title:
          The job title in the application. The API does an exact match
          on the [Job.title][google.cloud.talent.v4beta1.Job.title] of
          [Application.job][google.cloud.talent.v4beta1.Application.job]
          in profiles.
      negated:
          If true, the API excludes all profiles with any
          [Application.job][google.cloud.talent.v4beta1.Application.job]
          matching the filters.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ApplicationJobFilter)
    ),
)
_sym_db.RegisterMessage(ApplicationJobFilter)

TimeFilter = _reflection.GeneratedProtocolMessageType(
    "TimeFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TIMEFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Filter on create timestamp or update timestamp of
  profiles.
  
  
  Attributes:
      start_time:
          Start timestamp, matching profiles with the start time. If
          this field missing, The API matches profiles with create /
          update timestamp before the end timestamp.
      end_time:
          End timestamp, matching profiles with the end time. If this
          field missing, The API matches profiles with create / update
          timestamp after the start timestamp.
      time_field:
          Specifies which time field to filter profiles.  Defaults to [T
          imeField.CREATE\_TIME][google.cloud.talent.v4beta1.TimeFilter.
          TimeField.CREATE\_TIME].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.TimeFilter)
    ),
)
_sym_db.RegisterMessage(TimeFilter)

CandidateAvailabilityFilter = _reflection.GeneratedProtocolMessageType(
    "CandidateAvailabilityFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CANDIDATEAVAILABILITYFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Deprecated. Use AvailabilityFilter instead.
  
  Filter on availability signals.
  
  
  Attributes:
      negated:
          It is false by default. If true, API excludes all the
          potential available profiles.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CandidateAvailabilityFilter)
    ),
)
_sym_db.RegisterMessage(CandidateAvailabilityFilter)

AvailabilityFilter = _reflection.GeneratedProtocolMessageType(
    "AvailabilityFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_AVAILABILITYFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Filter on availability signals.
  
  
  Attributes:
      signal_type:
          Required. Type of signal to apply filter on.
      range:
          Required. Range of times to filter candidate signals by.
      required:
          If multiple [AvailabilityFilter][google.cloud.talent.v4beta1.A
          vailabilityFilter] are provided, the default behavior is to OR
          all filters, but if this field is set to true, this particular
          [AvailabilityFilter][google.cloud.talent.v4beta1.AvailabilityF
          ilter] will be AND'ed against other [AvailabilityFilter][googl
          e.cloud.talent.v4beta1.AvailabilityFilter].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.AvailabilityFilter)
    ),
)
_sym_db.RegisterMessage(AvailabilityFilter)

PersonNameFilter = _reflection.GeneratedProtocolMessageType(
    "PersonNameFilter",
    (_message.Message,),
    dict(
        DESCRIPTOR=_PERSONNAMEFILTER,
        __module__="google.cloud.talent_v4beta1.proto.filters_pb2",
        __doc__="""Filter on person name.
  
  
  Attributes:
      person_name:
          Required. The person name. For example, "John Smith".  Can be
          any combination of
          [PersonName.structured\_name.given\_name][],
          [PersonName.structured\_name.middle\_initial][],
          [PersonName.structured\_name.family\_name][], and [PersonName.
          formatted\_name][google.cloud.talent.v4beta1.PersonName.format
          ted\_name].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.PersonNameFilter)
    ),
)
_sym_db.RegisterMessage(PersonNameFilter)


DESCRIPTOR._options = None
_PROFILEQUERY.fields_by_name["candidate_availability_filter"]._options = None
_COMPENSATIONFILTER.fields_by_name["type"]._options = None
_COMPENSATIONFILTER.fields_by_name["units"]._options = None
_COMMUTEFILTER.fields_by_name["commute_method"]._options = None
_COMMUTEFILTER.fields_by_name["start_coordinates"]._options = None
_COMMUTEFILTER.fields_by_name["travel_duration"]._options = None
_JOBTITLEFILTER.fields_by_name["job_title"]._options = None
_SKILLFILTER.fields_by_name["skill"]._options = None
_EMPLOYERFILTER.fields_by_name["employer"]._options = None
_APPLICATIONOUTCOMENOTESFILTER.fields_by_name["outcome_notes"]._options = None
_CANDIDATEAVAILABILITYFILTER._options = None
_AVAILABILITYFILTER.fields_by_name["signal_type"]._options = None
_AVAILABILITYFILTER.fields_by_name["range"]._options = None
_PERSONNAMEFILTER.fields_by_name["person_name"]._options = None
# @@protoc_insertion_point(module_scope)
